==> aliyun-python-sdk-sas-2.0.0.tar.gz: aliyun-python-sdk-sas-2.0.0/aliyunsdksas/request/v20181203/CreateHoneypotRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class CreateHoneypotRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'CreateHoneypot')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_HoneypotName(self): # String
		return self.get_query_params().get('HoneypotName')

	def set_HoneypotName(self, HoneypotName):  # String
		self.add_query_param('HoneypotName', HoneypotName)
	def get_NodeId(self): # String
		return self.get_query_params().get('NodeId')

	def set_NodeId(self, NodeId):  # String
		self.add_query_param('NodeId', NodeId)
	def get_HoneypotImageId(self): # String
		return self.get_query_params().get('HoneypotImageId')

	def set_HoneypotImageId(self, HoneypotImageId):  # String
		self.add_query_param('HoneypotImageId', HoneypotImageId)
	def get_Meta(self): # String
		return self.get_query_params().get('Meta')

	def set_Meta(self, Meta):  # String
		self.add_query_param('Meta', Meta)
	def get_HoneypotImageName(self): # String
		return self.get_query_params().get('HoneypotImageName')

	def set_HoneypotImageName(self, HoneypotImageName):  # String
		self.add_query_param('HoneypotImageName', HoneypotImageName)

==> aliyun-python-sdk-sas-2.0.3.tar.gz: aliyun-python-sdk-sas-2.0.3/aliyunsdksas/request/v20181203/CreateHoneypotRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class CreateHoneypotRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'CreateHoneypot','sas')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_HoneypotName(self): # String
		return self.get_query_params().get('HoneypotName')

	def set_HoneypotName(self, HoneypotName):  # String
		self.add_query_param('HoneypotName', HoneypotName)
	def get_NodeId(self): # String
		return self.get_query_params().get('NodeId')

	def set_NodeId(self, NodeId):  # String
		self.add_query_param('NodeId', NodeId)
	def get_HoneypotImageId(self): # String
		return self.get_query_params().get('HoneypotImageId')

	def set_HoneypotImageId(self, HoneypotImageId):  # String
		self.add_query_param('HoneypotImageId', HoneypotImageId)
	def get_Meta(self): # String
		return self.get_query_params().get('Meta')

	def set_Meta(self, Meta):  # String
		self.add_query_param('Meta', Meta)
	def get_HoneypotImageName(self): # String
		return self.get_query_params().get('HoneypotImageName')

	def set_HoneypotImageName(self, HoneypotImageName):  # String
		self.add_query_param('HoneypotImageName', HoneypotImageName)
